window.Gleam.initSearch([{"doc":"stoiridh_version","title":"stoiridh_version","content":"&lt;p align=&quot;center&quot;&gt;\n  &lt;br&gt;\n  &lt;img alt=&quot;Stòiridh’s Version Logo&quot; src=&quot;./assets/logo.svg&quot; width=&quot;150&quot;&gt;\n  &lt;br&gt;\n&lt;/p&gt;\n\n# Stòiridh’s Version\n\n[![Package Version](https://img.shields.io/hexpm/v/stoiridh_version)](https://hex.pm/packages/stoiridh_version)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/stoiridh_version/)\n[![pipeline status](https://gitlab.com/stoiridh-project/stoiridh-version/badges/master/pipeline.svg)](https://gitlab.com/stoiridh-project/stoiridh-version/-/commits/master)\n\nStòiridh Version is a tiny library that implements the [Semantic Versioning Specification 2.0.0](https://semver.org/).\n\n## Installation\n\nIn your [Gleam](https://gleam.run/) project, you can add it by typing the following command in your terminal.\n\n```sh\ngleam add stoiridh_version\n```\n\n### Usage\n\n```gleam\nimport gleam/io\nimport gleam/result\nimport stoiridh/version\n\npub fn main() {\n  use v1 &lt;- result.map(\n    version.new(5, 12, 4)\n    |&gt; version.with_prerelease(&quot;alpha.20&quot;)\n    |&gt; version.with_build_metadata(&quot;49ae79&quot;),\n  )\n\n  use v2 &lt;- result.map(\n    version.parse(&quot;8.0.0&quot;)\n    |&gt; version.with_build_metadata(&quot;dev&quot;),\n  )\n\n  v1\n  |&gt; version.to_string\n  |&gt; io.println\n\n  v2\n  |&gt; version.to_string\n  |&gt; io.println\n\n  v1\n  |&gt; version.compare(v2)\n  |&gt; io.debug\n}\n```\n\n**Output:**\n\n```text\n5.12.4-alpha.20+49ae79\n8.0.0+dev\nLt\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/stoiridh_version&gt;.\n\n## Development\n\n```sh\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Sponsorship\n\nIf you’d like to support my work, you can consider &lt;script src=&quot;https://liberapay.com/viprip/widgets/button.js&quot;&gt;&lt;/script&gt;&lt;noscript&gt;&lt;a href=&quot;https://liberapay.com/viprip/donate&quot;&gt;&lt;img alt=&quot;Donate using Liberapay&quot; src=&quot;https://liberapay.com/assets/widgets/donate.svg&quot;&gt;&lt;/a&gt;&lt;/noscript&gt;. These donations will help me to continue my work on what I believe and share more projects.\n\n## Author\n\nThis library and the logo is a creation of [William McKIE](https://gitlab.com/viprip).\n\n## Licence\n\nCopyright © 2024 [William McKIE](https://gitlab.com/viprip).\n\nThis project is licenced under the [Apache License 2.0](https://choosealicense.com/licenses/apache-2.0/).","url":"index.html"},{"doc":"stoiridh/version","title":"Version","content":"pub opaque type Version\n A `Version` type.\n\n The `Version` type holds the values for constructing a semantic version.\n\nSynonyms:\nstoiridh/version.Version\nstoiridh/version Version","url":"stoiridh/version.html#Version"},{"doc":"stoiridh/version","title":"VersionError","content":"pub type VersionError {\n  InvalidVersion\n  InvalidMajorVersion\n  InvalidMinorVersion\n  InvalidPatchVersion\n  InvalidPrerelease\n  InvalidBuildMetadata\n  NegativeValue(String)\n}\n A type that holds errors when interacting with Semantic Versioning.\nInvalidVersion\n The version isn’t valid.\n\n An invalid version may be the result of an empty string or the failure of parsing a character\n as a digit for any `major`, `minor`, or `patch` version numbers.\n\nInvalidMajorVersion\n The major version number isn’t valid.\n\n This error raises when the [parse](#parse) function failed to parse the major version number.\n\nInvalidMinorVersion\n The minor version number isn’t valid.\n\n This error raises when the [parse](#parse) function failed to parse the minor version number.\n\nInvalidPatchVersion\n The patch version number isn’t valid.\n\n This error raises when the [parse](#parse) function failed to parse the patch version number.\n\nInvalidPrerelease\n The pre-release version isn’t valid.\n\n A valid pre-release version is a series of dot separated identifiers. Identifiers must\n comprise only ASCII alphanumerics and hyphens [A-Za-z0-9-]. Identifiers MUST NOT be empty.\n Numeric identifiers MUST NOT include leading zeroes.\n\nInvalidBuildMetadata\n The build metadata isn’t valid.\n\n A valid build metadata is a series of dot separated identifiers. Identifiers must\n comprise only ASCII alphanumerics and hyphens [A-Za-z0-9-]. Identifiers MUST NOT be empty.\n\nNegativeValue(String)\n Constructs a negative value error.\n\n This error is emitted when the version contains any negative value.\n\nSynonyms:\nstoiridh/version.VersionError\nstoiridh/version VersionError","url":"stoiridh/version.html#VersionError"},{"doc":"stoiridh/version","title":"build_metadata","content":"pub fn build_metadata(version: Version) -&gt; Option(String)\n Returns the build metadata of the version.\n\n # Example\n\n \n use v &lt;- result.map(\n   version.new(1, 0, 18)\n   |&gt; version.with_build_metadata(&quot;ae93d74&quot;),\n )\n\n v\n |&gt; version.build_metadata\n \n\n \n Some(&quot;ae93d74&quot;)\n \nSynonyms:\nstoiridh/version.build_metadata\nstoiridh/version build_metadata","url":"stoiridh/version.html#build_metadata"},{"doc":"stoiridh/version","title":"compare","content":"pub fn compare(a: Version, b: Version) -&gt; Order\n Compares two versions.\n\n The comparison of two versions `a` and `b` is carried out in two logical steps.\n\n The first step consists of comparing numerically the fields `major`, `minor`, and `patch` to\n find a difference. If the comparison results in equality, then we will proceed to the second\n step if and only if there is a presence of a pre-release label in either one or both versions.\n\n The second step consists of comparing each dot separated identifier of the pre-release label\n from both versions `a` and `b` until a difference is found. If a version has&#39;nt a pre-release\n label, then it will have a higher precedence than the other.\n\n Example: `1.2.3-alpha.1` &lt; `1.2.3`.\n\n # Example\n\n \n use v1 &lt;- result.map(version.new(1, 15, 0))\n use v2 &lt;- result.map(version.new(0, 30, 5))\n\n v1\n |&gt; version.compare(v2)\n \n\n \n order.Gt\n \n\n # Precedence\n\n Precedence for two pre-release versions with the same `major`, `minor` and `patch` field\n consists of comparing each dot separated identifier from left to right until a difference is\n found.\n\n - Identifiers consisting of only digits are compared numerically.\n - Identifiers with letters or hyphens are compared lexically in ASCII sort order.\n - Numeric identifiers always have a lower precedence than non-numeric identifiers.\n - A larget set of identifiers will always have a higher precedence than a smaller set if and\n   only if all of the preceding identifiers are equal.\n\n If there is no precedence and both versions are exactly the same, then the function will return\n `order.Eq`.\n\n \n use v &lt;- result.map(\n   version.new(1, 0, 0)\n   |&gt; version.with_prerelease(&quot;alpha.1.beta.2.gamma.3.---&quot;),\n )\n\n v\n |&gt; version.compare(v)\n \n\n \n order.Eq\n \n\n ## Precedence and Build Metadata\n\n According to the specification, the `build-metadata` label is ignored during the comparison.\n\n \n use v1 &lt;- result.map(\n   version.new(1, 15, 0)\n   |&gt; version.with_prerelease(&quot;alpha.1&quot;)\n   |&gt; version.with_build_metadata(&quot;aef1678&quot;),\n )\n\n use v2 &lt;- result.map(\n   version.new(1, 15, 0)\n   |&gt; version.with_prerelease(&quot;alpha.1&quot;),\n )\n\n v1\n |&gt; version.compare(v2)\n |&gt; should.equal(order.Eq)\n \n\n \n order.Eq\n \nSynonyms:\nstoiridh/version.compare\nstoiridh/version compare","url":"stoiridh/version.html#compare"},{"doc":"stoiridh/version","title":"major","content":"pub fn major(version: Version) -&gt; Int\n Returns the major version.\n\n # Example\n\n \n use v &lt;- result.map(version.new(1, 0, 18))\n\n v\n |&gt; version.major\n \n\n text\n 1\n \nSynonyms:\nstoiridh/version.major\nstoiridh/version major","url":"stoiridh/version.html#major"},{"doc":"stoiridh/version","title":"minor","content":"pub fn minor(version: Version) -&gt; Int\n Returns the minor version.\n\n # Example\n\n \n use v &lt;- result.map(version.new(1, 0, 18))\n\n v\n |&gt; version.minor\n \n\n text\n 0\n \nSynonyms:\nstoiridh/version.minor\nstoiridh/version minor","url":"stoiridh/version.html#minor"},{"doc":"stoiridh/version","title":"new","content":"pub fn new(\n  major: Int,\n  minor: Int,\n  patch: Int,\n) -&gt; Result(Version, VersionError)\n Creates a new semantic version.\n\n Any negative values on `major`, `minor`, or `patch` will result as an error.\nSynonyms:\nstoiridh/version.new\nstoiridh/version new","url":"stoiridh/version.html#new"},{"doc":"stoiridh/version","title":"parse","content":"pub fn parse(from input: String) -&gt; Result(Version, VersionError)\n Creates a new semantic version from a `String` representation.\n\n # Add or Override Pre-release and Build Metadata Labels.\n\n You can also use [with_prerelease](#with_prerelease) and [with_build_metadata](\n #with_build_metadata) after parsing a version successfully to whether add or override the\n pre-release and build metadata labels, respectively.\n\n ## Example\n\n \n use v &lt;- result.map(\n   version.parse(&quot;1.0.0-alpha.1&quot;)\n   |&gt; version.with_prerelease(&quot;beta.2&quot;)\n   |&gt; version.with_build_metadata(&quot;dev&quot;)\n )\n\n v\n |&gt; version.to_string\n |&gt; io.println\n \n\n text\n 1.0.0-beta.2+dev\n \nSynonyms:\nstoiridh/version.parse\nstoiridh/version parse","url":"stoiridh/version.html#parse"},{"doc":"stoiridh/version","title":"patch","content":"pub fn patch(version: Version) -&gt; Int\n Returns the patch version.\n\n # Example\n\n \n use v &lt;- result.map(version.new(1, 0, 18))\n\n v\n |&gt; version.patch\n \n\n text\n 18\n \nSynonyms:\nstoiridh/version.patch\nstoiridh/version patch","url":"stoiridh/version.html#patch"},{"doc":"stoiridh/version","title":"prerelease","content":"pub fn prerelease(version: Version) -&gt; Option(String)\n Returns the pre-release version.\n\n # Example\n\n \n use v &lt;- result.map(\n   version.new(1, 0, 18)\n   |&gt; version.with_prerelease(&quot;alpha.1&quot;),\n )\n\n v\n |&gt; version.prerelease\n \n\n \n Some(&quot;alpha.1&quot;)\n \nSynonyms:\nstoiridh/version.prerelease\nstoiridh/version prerelease","url":"stoiridh/version.html#prerelease"},{"doc":"stoiridh/version","title":"to_string","content":"pub fn to_string(version: Version) -&gt; String\n Converts a `Version` to a `String`.\n\n # Example\n\n \n use v &lt;- result.map(\n   version.new(1, 0, 18)\n   |&gt; version.with_prerelease(&quot;beta.8&quot;)\n   |&gt; version.with_build_metadata(&quot;dff999&quot;),\n )\n\n v\n |&gt; version.to_string\n |&gt; io.println\n \n\n text\n 1.0.1-beta.8+dff999\n \nSynonyms:\nstoiridh/version.to_string\nstoiridh/version to_string","url":"stoiridh/version.html#to_string"},{"doc":"stoiridh/version","title":"with_build_metadata","content":"pub fn with_build_metadata(\n  version: Result(Version, VersionError),\n  build_metadata: String,\n) -&gt; Result(Version, VersionError)\n Appends a build metadata to version.\n\n Build metadata are additional information that are ignored during version precedence. Examples:\n `1.0.0+a10234ff`, `1.0.0+a10234ff.001`, `1.0.0-alpha.1+bc632df`.\n\n # Error\n\n If `build_metadata` is not valid, the [`InvalidBuildMetadata`](#VersionError) error will return.\n\n # Example\n\n \n use v &lt;- result.map(\n   version.new(1, 0, 18)\n   |&gt; version.with_build_metadata(&quot;ae93d74&quot;),\n )\n \nSynonyms:\nstoiridh/version.with_build_metadata\nstoiridh/version with_build_metadata","url":"stoiridh/version.html#with_build_metadata"},{"doc":"stoiridh/version","title":"with_prerelease","content":"pub fn with_prerelease(\n  version: Result(Version, VersionError),\n  prerelease: String,\n) -&gt; Result(Version, VersionError)\n Appends a pre-release to version.\n\n A pre-release version indicates that the version is unstable and might not satisfy the intended\n compatibility requirements as denoted by its associated normal version. Examples: `1.0.0-alpha`,\n `1.0.0-alpha.1`, `1.0.0-0.3.7`, `1.0.0-x.7.z.92`, `1.0.0-x-y-z.--`.\n\n # Error\n\n If `prerelease` is not valid, then the [`InvalidPrerelease`](#VersionError) error will return.\n\n # Example\n\n \n use v &lt;- result.map(\n   version.new(1, 0, 18)\n   |&gt; version.with_prerelease(&quot;alpha.1&quot;),\n )\n \nSynonyms:\nstoiridh/version.with_prerelease\nstoiridh/version with_prerelease","url":"stoiridh/version.html#with_prerelease"},{"doc":"stoiridh/version","title":"stoiridh/version","content":" A module that contains types and functions to work with Semantic Versioning.\n\n Semantic Versioning (see [https://semver.org/](https://semver.org/)) is a specification that\n proposes a simple set of rules and requirements that dictate how version numbers are assigned\n and incremented.\n\n &gt; **NOTE:**\n &gt; This module follows the [Semantic Versioning specification 2.0](https://semver.org/spec/v2.0.0.html).\n\n ## Import\n\n To import the types and functions of this module, add the following import statement in your\n _gleam_ files:\n\n ```gleam\n import stoiridh/version\n ```\n\n ## Example\n\n This brief example gives an overview on how to use this module:\n\n ```gleam\n import gleam/io\n import gleam/result\n import stoiridh/version\n\n pub fn main() {\n   use v1 &lt;- result.map(\n     version.new(5, 12, 4)\n     |&gt; version.with_prerelease(&quot;alpha.20&quot;)\n     |&gt; version.with_build_metadata(&quot;49ae79&quot;),\n   )\n\n   use v2 &lt;- result.map(\n     version.new(8, 0, 0)\n     |&gt; version.with_build_metadata(&quot;dev&quot;),\n   )\n\n   v1\n   |&gt; version.to_string\n   |&gt; io.println\n\n   v2\n   |&gt; version.to_string\n   |&gt; io.println\n\n   v1\n   |&gt; version.compare(v2)\n   |&gt; io.debug\n }\n ```\n\n ```text\n 5.12.4-alpha.20+49ae79\n 8.0.0+dev\n Lt\n ```","url":"stoiridh/version.html"}]);